# Dish Account Service

>  [Tony MacDonell](mailto:TMacDonell@synacor.com), Synacor Inc.

The Dish Account Service is an Android application designed to perform user authentication on the [Evolve Set-Top device](https://www.dish.com/business/evolve/). The Account Service performs all authentication operations on behalf of apps on the device, and makes the resulting data available to any application whitelisted with the service.

## The Application APK files

Included with this package are 2 apk files:

#### `dish_account_service-1_1_0-signed.apk`

This application should be installed on the device before you get started. This application contains the Dish Account Service that will run the auth process and a settings user interface used to configure and monitor the servide.

##AuthService SDK

The AuthService SDK for Dish is an Android lib that can be included in any Android application and allows it to connect to the Account Service Application to perform authorization.

### Obtain the SDK:

First you need to include a reference to the Synacor dependency repository:

```
repositories {
    maven {
        url "http://android-sdks.uat-static-app.synacor.com/"
    }
}
```

Then include the following in your dependencies:

`compile "com.dish.accountservice:authservice:1.0.4"`

### Using the SDK

The class that you will use to perform auth is:

``com.synacor.cloudid.accountservice.remote.AuthService``

It is used like so:

```
AuthService.login(contextRef, (result, possibleException) -> {
	final String possibleErrorMessage = result.errorMessage;
	final String authZToken = result.token;
	final String[] channelList = result.channelLineup;
});
```

## Application UI

This application is designed to be a background service available to be utilized by other applications installed on the device. It does however, have a Settings and Monitoring user interface that can be used to control it's behaviour.

Once a version of the application is installed, go to the Android Launcher and look for an application called:

`Account Service` (it will have a Dish icon)

If you launch this application, you will be presented with a user interface that offers the following functionality:

### ITV Framework Status

This part of the Settings reports on the presence and status of Technicolor's ITVFramework service. This service must be present to aquire a VOD Token from the device itself. There are 3 possible status states:

* Not present on device. You will have to supply a VOD token manually to authenticate.
* Is present and functioning. We are using the VOD Token supplied by the system.
* Is present but not functioning. The device may not be authorized to supply a VOD token. You may supply a manual token instead.

### VOD Token

This part of the Settings will report on what VOD Token is currently being used by the Account Service. 

If it is running on an Evolve device, it is likely the VOD Token supplied by the ITV Framework will be displayed here by default. If there is no VOD Token, then you may manually supply one. The Wrench button will allow you to enter a VOD Token manually. The Eye icon will generate a QR Code of the current VOD Token being used (a useful feature when debugging on televisions).

For development purposes you may use a sample VOD Token by entering the following URL in the text entry field of the dialog presented when pushing the Wrench Button:

`http://android-sdks.uat-static-app.synacor.com/assets/vod_token.dat`

### Current Account

This section is where authentication can be performed manually. Press the Login button to run the process using the current VOD Token. If the process succeeds, you will see the authz token and the list of channels the user is entitled to displayed. If the process fails, you will see an explanation of the error that led to the failure.

This section will automatically display the current status of the current user. If a user has already logged in (even if a 3rd part app triggered it), it will be displayed here.

Once a user is logged in, you can use the Logout button to log the current user out.
